@@ -6,13 +6,12 @@
 #
 import logging
 import os
-import shutil
 import sys
 
 from compat import unittest
 
 # Always find our sources first
-sys.path.insert(0, '..')
+sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))
 import distlib_tests
 sys.path.pop(0)
 
@@ -21,7 +20,8 @@ def main():
     if '-v' in sys.argv:
         verbosity = 2
     loader = unittest.TestLoader()
-    runner = unittest.TextTestRunner(verbosity=verbosity)
+    failfast = 'FAILFAST' in os.environ
+    runner = unittest.TextTestRunner(verbosity=verbosity, failfast=failfast)
     results = runner.run(loader.loadTestsFromModule(distlib_tests))
     return not results.wasSuccessful()
 
