@@ -15,23 +15,20 @@ import re
 import shutil
 import sys
 import tempfile
-from textwrap import dedent
 
 from compat import unittest
 
 from distlib import DistlibException
-from distlib.compat import text_type, file_type, StringIO
-import distlib.database
-from distlib.metadata import Metadata, METADATA_FILENAME
+from distlib.compat import text_type, StringIO
+from distlib.metadata import Metadata, METADATA_FILENAME, LEGACY_METADATA_FILENAME
 from distlib.database import (InstalledDistribution, EggInfoDistribution,
                               BaseInstalledDistribution, EXPORTS_FILENAME,
                               DistributionPath, make_graph,
                               get_required_dists, get_dependent_dists)
-from distlib.util import (get_resources_dests, ExportEntry, CSVReader,
-                          read_exports, write_exports)
+from distlib.util import get_resources_dests, CSVReader, read_exports
 
 from test_util import GlobTestCaseBase
-from support import LoggingCatcher, requires_zlib
+from support import LoggingCatcher, requires_zlib, DistlibTestCase
 
 logger = logging.getLogger(__name__)
 
@@ -153,7 +150,7 @@ class CommonDistributionTests(FakeDistsMixin):
                     expected = '%s=%s' % (hasher, digest)
                 self.assertEqual(actual, expected)
 
-class TestDistribution(CommonDistributionTests, unittest.TestCase):
+class TestDistribution(CommonDistributionTests, DistlibTestCase):
 
     cls = InstalledDistribution
     sample_dist = 'choxie', '2.0.0.9', 'choxie-2.0.0.9.dist-info'
@@ -161,7 +158,7 @@ class TestDistribution(CommonDistributionTests, unittest.TestCase):
 
     def setUp(self):
         def get_files(location):
-            for path in ('REQUESTED', 'INSTALLER', 'METADATA',
+            for path in ('REQUESTED', 'INSTALLER', LEGACY_METADATA_FILENAME,
                          METADATA_FILENAME, EXPORTS_FILENAME):
                 p = os.path.join(location + '.dist-info', path)
                 if os.path.exists(p):
@@ -308,7 +305,7 @@ class TestDistribution(CommonDistributionTests, unittest.TestCase):
 
 class TestEggInfoDistribution(CommonDistributionTests,
                               LoggingCatcher,
-                              unittest.TestCase):
+                              DistlibTestCase):
 
     cls = EggInfoDistribution
     sample_dist = 'bacon', '0.1', 'bacon-0.1.egg-info'
@@ -351,7 +348,7 @@ class TestEggInfoDistribution(CommonDistributionTests,
 
 class TestDatabase(LoggingCatcher,
                    FakeDistsMixin,
-                   unittest.TestCase):
+                   DistlibTestCase):
 
     def setUp(self):
         super(TestDatabase, self).setUp()
@@ -581,8 +578,9 @@ class TestDatabase(LoggingCatcher,
         self.assertIn('real', d)
         e = d['real']
         self.check_entry(e, 'real', 'cgi', 'print_directory', [])
-        import cgi
-        self.assertIs(e.value, cgi.print_directory)
+        if sys.version_info[:2] < (3, 12):
+            import cgi
+            self.assertIs(e.value, cgi.print_directory)
 
         # See issue #78. Test reading an entry_points.txt with leading spaces
 
@@ -636,6 +634,13 @@ class TestDatabase(LoggingCatcher,
             expected.remove(t)
         self.assertFalse(expected)   # nothing left
 
+    def test_modules(self):
+        dp = DistributionPath(include_egg=True)
+        dist = dp.get_distribution('banana')
+        self.assertIsInstance(dist, EggInfoDistribution)
+        self.assertEqual(dist.modules, ['banana', 'cavendish'])
+
+
 class DataFilesTestCase(GlobTestCaseBase):
 
     def assertRulesMatch(self, rules, spec):
@@ -780,7 +785,7 @@ class DataFilesTestCase(GlobTestCaseBase):
 
 
 class DepGraphTestCase(LoggingCatcher,
-                       unittest.TestCase):
+                       DistlibTestCase):
 
     DISTROS_DIST = ('choxie', 'grammar', 'towel-stuff')
     DISTROS_EGG = ('bacon', 'banana', 'strawberry', 'cheese')
@@ -870,6 +875,7 @@ class DepGraphTestCase(LoggingCatcher,
         self.checkLists(graph.missing.get(cheese, []), [])
 
     def test_dependent_dists(self):
+        # import pdb; pdb.set_trace()
         dists = self.get_dists(self.DISTROS_DIST)
 
         choxie, grammar, towel = dists
